@@ -82,6 +82,8 @@ class FileScanner:
     def saveDatabase(self, db_name: str = "database.json") -> None:
         """Write database to config_dir on self and other if enabled"""
         self_entry = os.path.join(self.config_dir, "database")
+        if self.force_posix_path_sep:
+            self_entry = self_entry.replace(os.path.sep, "/")
         self_crc = self.calcDatabaseCrc(self.dict_current)
         assert self_entry not in self.dict_current
         self.dict_current[self_entry] = {"size": 0, "mtime": 0, "crc": self_crc, "dir": False}
@@ -119,6 +121,8 @@ class FileScanner:
     def verifyDatabaseCrc(self, database: dict, abs_db_path: str) -> None:
         """Verify the data in the database matches the CRC and pops the entry, otherwise raises exception"""
         self_entry = os.path.join(self.config_dir, "database")
+        if self.force_posix_path_sep:
+            self_entry = self_entry.replace(os.path.sep, "/")
         if self_entry in database:
             crc_record = database.pop(self_entry)["crc"]
             crc_calc = self.calcDatabaseCrc(database)
